// generated from rosidl_generator_c/resource/idl.h.em
// with input from std_msgs:msg/Header.idl
// generated code does not contain a copyright notice

#ifndef STD_MSGS__MSG__HEADER_H_
#define STD_MSGS__MSG__HEADER_H_

#include "std_msgs/msg/detail/header__struct.h"
#include "std_msgs/msg/detail/header__functions.h"
#include "std_msgs/msg/detail/header__type_support.h"

#endif  // STD_MSGS__MSG__HEADER_H_
